==> puppeteer-api-zh_cn-1.8.0.tgz: package/README.md <==
# Puppeteer 中文文档
[![npm](https://img.shields.io/npm/v/puppeteer-api-zh_cn.svg?style=flat)](https://github.com/zhaoqize/puppeteer-api-zh_CN)
[![GitHub license](https://img.shields.io/github/license/zhaoqize/puppeteer-api-zh_CN.svg)](https://github.com/zhaoqize/puppeteer-api-zh_CN/blob/master/LICENSE)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)]()

- [中文API网站](https://zhaoqize.github.io/puppeteer-api-zh_CN/)

- [中文API地址](./api.md)

- [官方API地址](https://github.com/GoogleChrome/puppeteer/blob/master/docs/api.md)

### 技术交流
<img src="./img/q.png" height="300">

### 贡献
[如何贡献](./CONTRIBUTING.md)
> [译文排版规则指北](https://github.com/xitu/gold-miner/wiki/%E8%AF%91%E6%96%87%E6%8E%92%E7%89%88%E8%A7%84%E5%88%99%E6%8C%87%E5%8C%97)


<h2 align="center">Maintainers</h2>

<table>
  <tbody>
    <tr>
      <td align="center">
        <a href="https://github.com/zhaoqize">
          <img width="150" height="150" src="https://github.com/zhaoqize.png?v=3&s=150">
          </br>
          zhaoqize
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/15vTechAdmin">
          <img width="150" height="150" src="https://github.com/15vTechAdmin.png?v=3&s=150">
          </br>
          15vTechAdmin
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/Gavin-Gong">
          <img width="150" height="150" src="https://github.com/Gavin-Gong.png?v=3&s=150">
          </br>
          Gavin-Gong
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/ilaipi">
          <img width="150" height="150" src="https://github.com/ilaipi.png?v=3&s=150">
          </br>
          ilaipi
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/abcdGJJ">
          <img width="150" height="150" src="https://github.com/abcdGJJ.png?v=3&s=150">
          </br>
          abcdGJJ
        </a>
      </td>
    </tr>
    <tr>
      <td align="center">
        <a href="https://github.com/jiangyx3915">
          <img width="150" height="150" src="https://github.com/jiangyx3915.png?v=3&s=150">
          </br>
          jiangyx3915
        </a>
      </td>
    <tr>
  <tbody>
</table>

==> puppeteer-api-zh_cn-1.9.0.tgz: package/README.md <==
# Puppeteer 中文文档
[![npm](https://img.shields.io/npm/v/puppeteer-api-zh_cn.svg?style=flat)](https://github.com/zhaoqize/puppeteer-api-zh_CN)
[![GitHub license](https://img.shields.io/github/license/zhaoqize/puppeteer-api-zh_CN.svg)](https://github.com/zhaoqize/puppeteer-api-zh_CN/blob/master/LICENSE)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)]()

- [Puppeteer中文社区](https://puppeteer-china.github.io/)

- [API中文网](https://zhaoqize.github.io/puppeteer-api-zh_CN/)

- [API官网](https://github.com/GoogleChrome/puppeteer/blob/master/docs/api.md)

### 技术交流

- [中文社区](https://github.com/orgs/puppeteer-china/teams/forum) (前提：先加入组织puppeteer-china)
- [Gitter](https://gitter.im/puppeteer-China/Lobby)
- [微信](https://github.com/zhaoqize/puppeteer-api-zh_CN/blob/master/img/wechat.jpeg)
- [QQ](https://github.com/zhaoqize/puppeteer-api-zh_CN/blob/master/img/qq.jpeg)

### 贡献
[如何贡献](./CONTRIBUTING.md)
> [译文排版规则指北](https://github.com/xitu/gold-miner/wiki/%E8%AF%91%E6%96%87%E6%8E%92%E7%89%88%E8%A7%84%E5%88%99%E6%8C%87%E5%8C%97)


<h2 align="center">贡献者</h2>

<table>
  <tbody>
    <tr>
      <td align="center">
        <a href="https://github.com/zhaoqize">
          <img width="150" height="150" src="https://github.com/zhaoqize.png?v=3&s=150">
          </br>
          zhaoqize
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/15vTechAdmin">
          <img width="150" height="150" src="https://github.com/15vTechAdmin.png?v=3&s=150">
          </br>
          15vTechAdmin
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/Gavin-Gong">
          <img width="150" height="150" src="https://github.com/Gavin-Gong.png?v=3&s=150">
          </br>
          Gavin-Gong
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/ilaipi">
          <img width="150" height="150" src="https://github.com/ilaipi.png?v=3&s=150">
          </br>
          ilaipi
        </a>
      </td>
      <td align="center">
        <a href="https://github.com/abcdGJJ">
          <img width="150" height="150" src="https://github.com/abcdGJJ.png?v=3&s=150">
          </br>
          abcdGJJ
        </a>
      </td>
    </tr>
    <tr>
      <td align="center">
        <a href="https://github.com/jiangyx3915">
          <img width="150" height="150" src="https://github.com/jiangyx3915.png?v=3&s=150">
          </br>
          jiangyx3915
        </a>
      </td>
    <tr>
  <tbody>
</table>
